@@ -181,24 +181,24 @@ tukeyPsi <- c() ##########
 
 ## to use for other types, just change 'ggw' argument
 ## standardized to have Dpsi(0) = 1
-## to have rho(inf) = 1 use lmrob.chifun instead (as well as deriv + 1)
+## to have rho(inf) = 1 use .M.chi instead (as well as deriv + 1)
 ## using this results in an error while preparing for lazy loading:
 ## (MM, MK: the error arises during the validity check)
 ## ** preparing package for lazy loading
 ## Creating a generic function from function "chgDefaults"
-## Error in lmrob.psifun(x, k, "ggw", -1) : object 'R_psifun' not found
+## Error in .M.psi(x, k, "ggw", -1) : object 'R_psifun' not found
 ## Error : unable to load R code in package 'robustbase'
 ## ERROR: lazy loading failed for package ‘robustbase’
-## ('R_psifun' is the pointer to the C-function used in lmrob.psifun)
-ggwPsi <- psiFunc(rho = function(x, k) lmrob.psifun(x, k, 'ggw', -1),
-                  psi = function(x, k) lmrob.psifun(x, k, 'ggw', 0),
-                  wgt = function(x, k) lmrob.wgtfun(x, k, 'ggw'),
-                  Dpsi = function(x, k) lmrob.psifun(x, k, 'ggw', 1),
-                  Erho = function(k) lmrob.E(lmrob.psifun(r, k, 'ggw', -1),
+## ('R_psifun' is the pointer to the C-function used in .M.psi)
+ggwPsi <- psiFunc(rho = function(x, k) .M.psi(x, k, 'ggw', -1),
+                  psi = function(x, k) .M.psi(x, k, 'ggw', 0),
+                  wgt = function(x, k) .M.wgt(x, k, 'ggw'),
+                  Dpsi = function(x, k) .M.psi(x, k, 'ggw', 1),
+                  Erho = function(k) lmrob.E(.M.psi(r, k, 'ggw', -1),
                     use.integrate = TRUE),
-                  Epsi2 = function(k) lmrob.E(lmrob.psifun(r, k, 'ggw', 0)^2,
+                  Epsi2 = function(k) lmrob.E(.M.psi(r, k, 'ggw', 0)^2,
                     use.integrate = TRUE),
-                  EDpsi = function(k) lmrob.E(lmrob.psifun(r, k, 'ggw', 1),
+                  EDpsi = function(k) lmrob.E(.M.psi(r, k, 'ggw', 1),
                     use.integrate = TRUE),
                   k = c(-0.5, 1.5, 0.95, NA))
 
